# Changelog

All notable changes to this project will be documented in this file.

## [1.0.5] - 2024-03-14

* Made the rust code faster by not opening the ref genome file for each mutation but read the mutation per chromosome

## [1.0.4] - 2024-02-21

* Fix for the reverse complementary translating

## [1.0.3] - 2024-02-19

* Broke down the rust funciton into multiple functions
* Added information about the input in the readme
